Arithmetic Subgroups of `\SL_2(\ZZ)`
====================================

This chapter describes the basic functionality for finite index subgroups of
the modular group `\SL_2(\ZZ)`.

.. toctree::
   :maxdepth: 1

   sage/modular/arithgroup/arithgroup_generic
   sage/modular/arithgroup/arithgroup_perm
   sage/modular/arithgroup/arithgroup_element
   sage/modular/arithgroup/congroup_generic
   sage/modular/arithgroup/congroup_gammaH
   sage/modular/arithgroup/congroup_gamma1
   sage/modular/arithgroup/congroup_gamma0
   sage/modular/arithgroup/congroup_gamma
   sage/modular/arithgroup/congroup_sl2z
   sage/modular/arithgroup/farey_symbol
   sage/modular/arithgroup/congroup

.. include:: ../footer.txt
